@@ -24,11 +24,10 @@ sub id {
     $self->_accessor( "id", @_ );
 }
 
-## deprecated. Let the base class handle this.
-#    sub store {
-#        my $self = shift;
-#        $self->_accessor( "store", @_ ) || ref $self;
-#    }
+sub store {
+    my $self = shift;
+    ref $self || $self;
+}
 
 sub _accessor {
     my $self = shift;
@@ -45,7 +44,6 @@ sub _accessor {
       : $data;
 }
 
-## password portion of this is no longer necessary, but here for backwards compatibility.
 my %features = (
     password => {
         clear      => ["password"],
@@ -66,7 +64,8 @@ sub supports {
 
     # traverse the feature list,
     for (@spec) {
-        return if ref($cursor) ne "HASH";
+        die "bad feature spec: @spec"
+          if ref($cursor) ne "HASH";
         $cursor = $cursor->{$_};
     }
 
@@ -87,7 +86,7 @@ sub supports {
 
 sub for_session {
     my $self = shift;
-    return $self->store && $self->id || $self; # if we have a store and an ID we serialize by ref, otherwise we serialize the whole user
+    return $self;    # let's hope we're serialization happy
 }
 
 sub from_session {
